@@ -4,8 +4,7 @@ module.exports = definitions
 const Definition = require('./definition.js')
 
 const { version: npmVersion } = require('../../../package.json')
-const ciDetect = require('@npmcli/ci-detect')
-const ciName = ciDetect()
+const ciInfo = require('ci-info')
 const querystring = require('querystring')
 const { isWindows } = require('../is-windows.js')
 const { join } = require('path')
@@ -433,7 +432,7 @@ define('cert', {
 })
 
 define('ci-name', {
-  default: ciName || null,
+  default: ciInfo.name ? ciInfo.name.toLowerCase().split(' ').join('-') : null,
   defaultDescription: `
     The name of the current CI system, or \`null\` when not on a known CI
     platform.
@@ -442,7 +441,7 @@ define('ci-name', {
   description: `
     The name of a continuous integration system.  If not set explicitly, npm
     will detect the current CI environment using the
-    [\`@npmcli/ci-detect\`](http://npm.im/@npmcli/ci-detect) module.
+    [\`ci-info\`](http://npm.im/@npmcli/ci-info) module.
   `,
   flatten,
 })
@@ -1597,7 +1596,7 @@ define('production', {
 })
 
 define('progress', {
-  default: !ciName,
+  default: !ciInfo.isCI,
   defaultDescription: `
     \`true\` unless running in a known CI system
   `,
